@@ -4,9 +4,7 @@ import dask.array as np
 import dask.dataframe as pd
 import numpy
 import pandas
-from triad.utils.assertion import assert_or_throw
-
-from qpd import QPDEngine, run_sql
+from qpd import PandasLikeUtils, QPDEngine, run_sql
 from qpd.dataframe import Column, DataFrame
 from qpd.specs import (
     AggFunctionSpec,
@@ -16,6 +14,7 @@ from qpd.specs import (
     WindowFunctionSpec,
 )
 from qpd_pandas.engine import _RowsIndexer
+from triad.utils.assertion import assert_or_throw
 
 
 def run_sql_on_dask(
@@ -24,7 +23,15 @@ def run_sql_on_dask(
     return run_sql(QPDDaskEngine(), sql, dfs, ignore_case=ignore_case)
 
 
+class DaskUtils(PandasLikeUtils[pd.DataFrame, pd.Series]):
+    pass
+
+
 class QPDDaskEngine(QPDEngine):
+    @property
+    def pl_utils(self) -> DaskUtils:
+        return DaskUtils()
+
     def to_df(self, obj: Any) -> DataFrame:
         if isinstance(obj, DataFrame):
             return obj
